<?php
/*
Fruity - A Nagios Configuration Tool
Copyright (C) 2005 Groundwork Open Source Solutions

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

/*
	Filename: fruity.inc
	Description:
	The class definition for fruity
*/

class fruityclass {
	// Database connection parameters
	private $dbServ;	// Either mysql or sqlite
	private $dbHost;
	private $dbUsername;
	private $dbPassword;
	private $dbDatabase;

	// Internal Variables
	private $authHandler = null;  // Can only have one authentication module
	private $activatedModules = array();	// Array to hold all activated component modules
	private $errorMsg = null;	// Holds the last error message (that is considered non fatal).
	private $dbConnection = null;	// To hold the adoDB connection
	public $outputHandler = null;
	
	function __construct() {
		global $sitedb_config;
		$this->dbServ = $sitedb_config['dbserv'];
		$this->dbHost = $sitedb_config['host'];
		$this->dbUsername = $sitedb_config['username'];
		$this->dbPassword = $sitedb_config['password'];
		$this->dbDatabase = $sitedb_config['database'];
		
		
		// Setup internal variables
		$this->outputHandler = new fruityOutput;
		// Connect database
		$this->dbConnection = ADONewConnection($this->dbServ);
		$this->dbConnection->PConnect($this->dbHost, $this->dbUsername,
							$this->dbPassword,$this->dbDatabase);
		if(!$this->dbConnection->IsConnected()) {
			print("Unable to connect to database.  Please check your configuration.");
			die();
		}
		$this->dbConnection->SetFetchMode(ADODB_FETCH_ASSOC);	
		
	}
	function init() {
		// Let's validate the session
		session_start();	// Restart Session
		if($_SESSION["session_secret"] <> SESSION_SECRET || $_SESSION['logged_in'] == '0') {
			// Let's initialize the session and call our AuthHandler			
			session_register("logged_in");
			$_SESSION["logged_in"] = 0;
			session_register("username");
			$_SESSION["username"] = NULL;
			session_register("session_secret");
			$_SESSION["session_secret"] = SESSION_SECRET;
			$this->authHandler->login($this);
		}
		// If we got here, we're good to go.
	}
	function logout_user() {
		$this->authHandler->logout();
	}
	function setAuthHandler($authObject) {
		if($this->authHandler != NULL) {
			// We're only supposed to have one authhandler.  It was already 
			// set.  Therefore, we'll perform a fatal error.
			print_error(1000, "Error assigning Fruity's Authentication Handler.  A Authentication Handler was already assigned!", 1);
		}
		else {
			$this->authHandler = $authObject;
			$this->authHandler->init($this);
		}
	}
	function setErrorMsg($error_msg) {
		$this->errorMsg = $error_msg;
	}

	function hasPrivilege($priv) {
		return $this->authHandler->hasPrivilege($priv);
	}
	function ErrorMsgSet() {
		if($this->errorMsg != NULL) return true;
		else return false;
	}
	function ErrorMsg($erase = 0) {
		$tempMsg = $this->errorMsg;
		if($erase)
			$this->errorMsg = NULL;
		return $tempMsg;
	}
	
	
	function __destruct() {
	}
	function get_toplevel_hosts_list(&$children_lists) {
		$children_lists = NULL;
		$query = "SELECT host_id, host_name, alias FROM nagios_hosts WHERE parents = '0'";
		$result = $this->dbConnection->Execute($query);
		while (! $result->EOF)
		{
			$children_lists[] = $result->fields;
			$result->MoveNext();
		}
		
		return 1;
	}
	function get_children_hosts_list($host_id, &$children_lists) {
		$children_lists = NULL;
		if($host_id == 0)
			$query = "SELECT host_id, host_name, alias FROM nagios_hosts WHERE parents IS NULL";
		else
			$query = "SELECT host_id, host_name, alias FROM nagios_hosts WHERE parents = '$host_id'";
		$result = $this->dbConnection->Execute($query);
		while (! $result->EOF)
		{
			$children_lists[] = $result->fields;
			$result->MoveNext();
		}
		
		return 1;
	}
	function return_period_list(&$period_list) {
		$query = "SELECT timeperiod_id,timeperiod_name,alias FROM nagios_timeperiods ORDER BY timeperiod_name ASC";
		$result = $this->dbConnection->Execute($query);	
		if ($result == false)
		{
			print $this->dbConnection->ErrorMsg();
			return E_QUERY_FAILED;
		}
		while (! $result->EOF)
		{
			$period_list[] = $result->fields;
			$result->MoveNext();
		}
		
		return 1;
	}
	function get_contactgroup_list(&$contactgroups_list) {
		$contactgroups_list = NULL;
		$query = "SELECT contactgroup_id, contactgroup_name, alias FROM nagios_contactgroups";
		$result = $this->dbConnection->Execute($query);
		while (! $result->EOF)
		{
			$contactgroups_list[] = $result->fields;
			$result->MoveNext();
		}
		
		return 1;
	}
	function element_desc($element, $table)
	{
		$query = "SELECT field_desc FROM $table WHERE field_name = '$element'";
		$result = $this->dbConnection->Execute($query);
		return $result->fields['field_desc'];
	}
	function contactgroup_exists($contactgroup_name) {
		$query = "SELECT contactgroup_id FROM nagios_contactgroups WHERE contactgroup_name LIKE '$contactgroup_name'";
		$result = $this->dbConnection->Execute($query);	
		if(!$result->EOF) {
			return true;
		}
		else {
			return false;
		}
	}
	
	function host_template_exists($template_name) {
		$query = "SELECT host_template_id FROM nagios_host_templates WHERE template_name LIKE '$template_name'";
		$result = $this->dbConnection->Execute($query);	
		if(!$result->EOF) {
			return true;
		}
		else {
			return false;
		}
	}
	
	function service_template_exists($template_name) {
		$query = "SELECT service_template_id FROM nagios_service_templates WHERE template_name LIKE '$template_name'";
		$result = $this->dbConnection->Execute($query);	
		if(!$result->EOF) {
			return true;
		}
		else {
			return false;
		}
	}	
	
	function get_command($command_id, &$commandInfo) {
		$query = "SELECT * FROM nagios_commands WHERE command_id = '$command_id'";
		$result = $this->dbConnection->Execute($query);
		$commandInfo = $result->fields;
	}
	
	function get_host_extended_info($host_id, &$extended_info) {
		$query = "SELECT * FROM nagios_hosts_extended_info WHERE host_id = '$host_id'";
		$result = $this->dbConnection->Execute($query);
		if($result) {
			$extended_info = $result->fields;
			return true;
		}
		else 
			return false;
	}
	
	function get_host_template_extended_info($host_template_id, &$extended_info) {
		$extended_info = NULL;
		$query = "SELECT * FROM nagios_host_template_extended_info WHERE host_template_id = '$host_template_id'";
		$result = $this->dbConnection->Execute($query);
		if($result) {
			$extended_info = $result->fields;
			return true;
		}
		else 
			return false;
	}
	
	function get_service_template_extended_info($service_template_id, &$extended_info) {
		$extended_info = NULL;
		$query = "SELECT * FROM nagios_service_template_extended_info WHERE service_template_id = '$service_template_id'";
		$result = $this->dbConnection->Execute($query);
		if($result) {
			$extended_info = $result->fields;
			return true;
		}
		else 
			return false;
	}
	
	function get_service_extended_info($service_id, &$extended_info) {
		$query = "SELECT * FROM nagios_services_extended_info WHERE service_id = '$service_id'";
		$result = $this->dbConnection->Execute($query);
		if($result) {
			$extended_info = $result->fields;
			return true;
		}
		else 
			return false;
	}
	
	function return_command_name($command_id) {
		$query = "SELECT command_name FROM nagios_commands WHERE command_id = '$command_id'";
		$result = $this->dbConnection->Execute($query);
		return $result->fields['command_name'];
	}
	
	function get_cgi_conf(&$cgi_conf) {
		$query = "SELECT * FROM nagios_cgi";
		$result = $this->dbConnection->Execute($query);
		$cgi_conf = $result->fields;
	}
	
	
	function get_resource_conf(&$resource_conf) {
		$query = "SELECT * FROM nagios_resources";
		$result = $this->dbConnection->Execute($query);
		$resource_conf = $result->fields;
	}
	
	function update_resource_conf($resource_conf) {
		$query = "DELETE FROM nagios_resources";
		$result = $this->dbConnection->Execute($query);
		$query = "INSERT INTO nagios_resources (";
		$query .= implode(", ", array_keys($resource_conf));
		$query .= ") VALUES ('";
	
		$query .= implode("', '", array_values($resource_conf));
		$query .= "')";
		$result = $this->dbConnection->Execute($query);
	}
	
	function update_main_conf($main_conf) {
		$query = "SELECT * FROM nagios_main";
		$result = $this->dbConnection->Execute($query);
		$query = $this->dbConnection->GetUpdateSQL($result, $main_conf,1);
		$result = $this->dbConnection->Execute($query);
		if($result)
			return true;
		else 
			return false;
	}
	
	function get_main_conf(&$main_config) {
		$query = "SELECT * FROM nagios_main";
		$result = $this->dbConnection->Execute($query);
		$main_config = $result->fields;
	}
	
	function update_cgi_conf($cgi_conf) {
		$query = "SELECT * FROM nagios_cgi";
		$result = $this->dbConnection->Execute($query);
		$query = $this->dbConnection->GetUpdateSQL($result, $cgi_conf,1);
		$result = $this->dbConnection->Execute($query);
		if($result)
			return true;
		else 
			return false;
	}
	
	function modify_host_extended($host_id, $extended_info) {
		$query = "SELECT * FROM nagios_hosts_extended_info WHERE host_id = '".$host_id."'";
		$result = $this->dbConnection->Execute($query);
		$query = $this->dbConnection->GetUpdateSQL($result,$extended_info,1);
		$result = $this->dbConnection->Execute($query);
	}
	

	function modify_host_template_extended($host_template_id, $extended_info) {
		$query = "SELECT * FROM nagios_host_template_extended_info WHERE host_template_id = '".$host_template_id."'";
		$result = $this->dbConnection->Execute($query);
		$query = $this->dbConnection->GetUpdateSQL($result,$extended_info,1);
		$result = $this->dbConnection->Execute($query);		
	}	
	
	function modify_service_template_extended($service_template_id, $extended_info) {
		$query = "SELECT * FROM nagios_service_template_extended_info WHERE service_template_id = '".$service_template_id."'";
		$result = $this->dbConnection->Execute($query);
		$query = $this->dbConnection->GetUpdateSQL($result,$extended_info,1);
		$result = $this->dbConnection->Execute($query);		
	}
	
	function modify_service_extended($service_id, $extended_info) {
		$query = "DELETE FROM nagios_services_extended_info WHERE service_id = '$service_id'";
		$result = $this->dbConnection->Execute($query);
		$query = "INSERT INTO nagios_services_extended_info (";
		$query .= implode(", ", array_keys($extended_info));
		$query .= ") VALUES ('";
	
		$query .= implode("', '", array_values($extended_info));
		$query .= "')";
		$result = $this->dbConnection->Execute($query);
	
	}
	
	
	function new_main_conf($main_conf, $config_dir) {
		$main_conf['illegal_object_name_chars'] = addslashes($main_conf['illegal_object_name_chars']);
		$main_conf['illegal_macro_output_chars'] = addslashes($main_conf['illegal_macro_output_chars']);

		unset($main_conf['resource_file']);
		$main_conf['config_dir'] = $config_dir;
		$query = "DELETE FROM nagios_main";
		$result = $this->dbConnection->Execute($query);
		$query = "INSERT INTO nagios_main (";
		$query .= implode(", ", array_keys($main_conf));
		$query .= ") VALUES ('";
	
		$query .= implode("', '", array_values($main_conf));
		$query .= "')";
		$result = $this->dbConnection->Execute($query);
		if($result)
			return true;
		else 
			return false;
	}
	
	function new_cgi_conf($cgi_conf) {
		if(is_array($cgi_conf)) {
			$query = "DELETE FROM nagios_cgi";
			$result = $this->dbConnection->Execute($query);
			$query = "INSERT INTO nagios_cgi (";
			$query .= implode(", ", array_keys($cgi_conf));
			$query .= ") VALUES ('";
		
			$query .= implode("', '", array_values($cgi_conf));
			$query .= "')";
			$result = $this->dbConnection->Execute($query);
			if($result)
				return true;
			else 
				return false;
		}
		else
			return false;
	}
	
	
	function get_period($timeperiod_id, &$periodInfo) {
		$query = "SELECT * FROM nagios_timeperiods WHERE timeperiod_id = '$timeperiod_id'";
		$result = $this->dbConnection->Execute($query);
		$periodInfo = $result->fields;
	}
	
	function return_period_id_by_name($name) {
		$query = "SELECT timeperiod_id FROM nagios_timeperiods WHERE timeperiod_name LIKE '$name'";
		$result = $this->dbConnection->Execute($query);
		if($result->EOF)
			return false;
		else 
			return $result->fields['timeperiod_id'];
	}
	
	function return_contact_id_by_name($name) {
		$query = "SELECT contact_id FROM nagios_contacts WHERE contact_name LIKE '$name'";
		$result = $this->dbConnection->Execute($query);
		if($result->EOF)
			return false;
		else 
			return $result->fields['contact_id'];
	}
	
	function return_command_id_by_name($name) {
		$query = "SELECT command_id FROM nagios_commands WHERE command_name LIKE '$name'";
		$result = $this->dbConnection->Execute($query);
		if($result->EOF)
			return false;
		else 
			return $result->fields['command_id'];
	}
	
	function return_contactgroup_id_by_name($name) {
		$query = "SELECT contactgroup_id FROM nagios_contactgroups WHERE contactgroup_name LIKE '$name'";
		$result = $this->dbConnection->Execute($query);
		if($result->EOF)
			return false;
		else 
			return $result->fields['contactgroup_id'];
	}
	
	function return_host_id_by_name($name) {
		$query = "SELECT host_id FROM nagios_hosts WHERE host_name LIKE '$name'";
		$result = $this->dbConnection->Execute($query);
		if($result->EOF)
			return false;
		else 
			return $result->fields['host_id'];
	}
	
	function return_host_template_id_by_name($name) {
		$query = "SELECT host_template_id FROM nagios_host_templates WHERE template_name LIKE '$name'";
		$result = $this->dbConnection->Execute($query);
		if($result->EOF)
			return false;
		else 
			return $result->fields['host_template_id'];
	}

	function return_service_template_id_by_name($name) {
		$query = "SELECT service_template_id FROM nagios_service_templates WHERE template_name LIKE '$name'";
		$result = $this->dbConnection->Execute($query);
		if($result->EOF)
			return false;
		else 
			return $result->fields['service_template_id'];
	}	
	
	function return_hostgroup_id_by_name($name) {
		$query = "SELECT hostgroup_id FROM nagios_hostgroups WHERE hostgroup_name LIKE '$name'";
		$result = $this->dbConnection->Execute($query);
		if($result->EOF)
			return false;
		else 
			return $result->fields['hostgroup_id'];
	}
	
	function return_servicegroup_id_by_name($name) {
		$query = "SELECT servicegroup_id FROM nagios_servicegroups WHERE servicegroup_name LIKE '$name'";
		$result = $this->dbConnection->Execute($query);
		if($result->EOF)
			return false;
		else 
			return $result->fields['servicegroup_id'];
	}
	
	function return_service_id_by_host_and_description($host_id, $description) {
		$query = "SELECT service_id FROM nagios_services WHERE host_id = '$host_id' AND service_description = '$description'";
		$result = $this->dbConnection->Execute($query);
		if($result->EOF)
			return false;
		else 
			return $result->fields['service_id'];
	}
	
	function return_service_id_by_host_template_and_description($host_template_id, $description) {
		$query = "SELECT service_id FROM nagios_services WHERE host_template_id = '$host_template_id' AND service_description = '$description'";
		$result = $this->dbConnection->Execute($query);
		if($result->EOF)
			return false;
		else 
			return $result->fields['service_id'];
	}
	
	function return_service_id_by_hostgroup_and_description($hostgroup_id, $description) {
		$query = "SELECT service_id FROM nagios_services WHERE hostgroup_id = '$hostgroup_id' AND service_description = '$description'";
		$result = $this->dbConnection->Execute($query);
		if($result->EOF)
			return false;
		else 
			return $result->fields['service_id'];
	}
	
	function return_service_id_by_description($description) {
		$query = "SELECT service_id FROM nagios_services WHERE service_description = '$description'";
		$result = $this->dbConnection->Execute($query);
		if($result->EOF)
			return false;
		else 
			return $result->fields['service_id'];
	}
		
	function return_command_list(&$command_list) {
		$query = "SELECT command_id,command_name,command_desc FROM nagios_commands ORDER BY command_name ASC";
		$result = $this->dbConnection->Execute($query);	
		if ($result == false)
		{
			print $this->dbConnection->ErrorMsg();
			return E_QUERY_FAILED;
		}
		while (! $result->EOF)
		{
			$command_list[] = $result->fields;
			$result->MoveNext();
		}
		
		return 1;
	}
	
	function get_service_hosts($service_id, &$host_list) {
		$query = "SELECT * FROM nagios_host_services WHERE service_id = '$service_id'";
		$result = $this->dbConnection->Execute($query);	
		if ($result == false)
		{
			print $this->dbConnection->ErrorMsg();
			return E_QUERY_FAILED;
		}
		while (! $result->EOF)
		{
			$host_list[] = $result->fields;
			$result->MoveNext();
		}
		
		return 1;
	}
	
	function get_service_hostgroups($service_id, &$host_list) {
		$query = "SELECT * FROM nagios_hostgroup_services WHERE service_id = '$service_id'";
		$result = $this->dbConnection->Execute($query);	
		if ($result == false)
		{
			print $this->dbConnection->ErrorMsg();
			return E_QUERY_FAILED;
		}
		while (! $result->EOF)
		{
			$host_list[] = $result->fields;
			$result->MoveNext();
		}
		
		return 1;
	}
	
	function command_exists($command_name) {
		$query = "SELECT command_id FROM nagios_commands WHERE command_name LIKE '$command_name'";
		$result = $this->dbConnection->Execute($query);	
		if(!$result->EOF) {
			return true;
		}
		else {
			return false;
		}
	}
	
	function host_exists($host_name) {
		$query = "SELECT host_id FROM nagios_hosts WHERE host_name LIKE '$host_name'";
		$result = $this->dbConnection->Execute($query);	
		if(!$result->EOF) {
			return true;
		}
		else {
			return false;
		}
	}
	
	function service_exists($service_info) {
		$query = "SELECT service_id FROM nagios_services WHERE service_description LIKE '".$service_info['service_description']."'";
		if(isset($service_info['host_id'])) {
			$query .= " AND host_id = '".$service_info['host_id']."'";
		}
		else {
			$query .= " AND host_template_id = '".$service_info['host_template_id']."'";
		}
		$result = $this->dbConnection->Execute($query);	
		if(!$result->EOF) {
			return true;
		}
		else {
			return false;
		}
	}
	
	function contact_exists($contact_name) {
		$query = "SELECT contact_id FROM nagios_contacts WHERE contact_name LIKE '$contact_name'";
		$result = $this->dbConnection->Execute($query);	
		if(!$result->EOF) {
			return true;
		}
		else {
			return false;
		}
	}
	
	
	
	function hostgroup_exists($hostgroup_name) {
		$query = "SELECT hostgroup_id FROM nagios_hostgroups WHERE hostgroup_name LIKE '$hostgroup_name'";
		$result = $this->dbConnection->Execute($query);	
		if(!$result->EOF) {
			return true;
		}
		else {
			return false;
		}
	}
	
	function servicegroup_exists($servicegroup_name) {
		$query = "SELECT servicegroup_id FROM nagios_servicegroups WHERE servicegroup_name LIKE '$servicegroup_name'";
		$result = $this->dbConnection->Execute($query);	
		if(!$result->EOF) {
			return true;
		}
		else {
			return false;
		}
	}
	
	function period_exists($period_name) {
		$query = "SELECT timeperiod_id FROM nagios_timeperiods WHERE timeperiod_name LIKE '$period_name'";
		$result = $this->dbConnection->Execute($query);	
		if(!$result->EOF) {
			return true;
		}
		else {
			return false;
		}
	}
	
	function prepare_for_sql(&$text) {
		$text = addslashes($text);
	}
	
	function add_command($command) {
		$query = "INSERT INTO nagios_commands (";
		$query .= implode(", ", array_keys($command));
		$query .= ") VALUES ('";
		$query .= implode("', '", array_values($command));
		$query .= "')";
		$result = $this->dbConnection->Execute($query);
		if($result)
			return true;
		else 
			return false;
	}
	
function add_contact($contact) {
	
	$query = "INSERT INTO nagios_contacts (";
	$query .= implode(", ", array_keys($contact));
   	$query .= ") VALUES ('";

  	$query .= implode("', '", array_values($contact));
   	$query .= "')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function return_num_of_children($host_id) {
	
	$query = "SELECT host_id FROM nagios_hosts WHERE parents = '$host_id'";
	$result = $this->dbConnection->Execute($query);
	return $this->dbConnection->Affected_Rows();
}

function add_contactgroup($contactgroup) {
	
	$query = "INSERT INTO nagios_contactgroups (";
	$query .= implode(", ", array_keys($contactgroup));
   	$query .= ") VALUES ('";

  	$query .= implode("', '", array_values($contactgroup));
   	$query .= "')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function add_hostgroup($hostgroup) {
	
	$query = "INSERT INTO nagios_hostgroups (";
	$query .= implode(", ", array_keys($hostgroup));
   	$query .= ") VALUES ('";

  	$query .= implode("', '", array_values($hostgroup));
   	$query .= "')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function add_servicegroup($servicegroup) {
	
	$query = "INSERT INTO nagios_servicegroups (";
	$query .= implode(", ", array_keys($servicegroup));
   	$query .= ") VALUES ('";

  	$query .= implode("', '", array_values($servicegroup));
   	$query .= "')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else {
		return false;
	}
}

function add_period($timeperiod) {
	
	$query = "INSERT INTO nagios_timeperiods (";
	$query .= implode(", ", array_keys($timeperiod));
   	$query .= ") VALUES ('";

  	$query .= implode("', '", array_values($timeperiod));
   	$query .= "')";
	$result = $this->dbConnection->Execute($query);
	print($this->dbConnection->ErrorMsg());
	if($result)
		return true;
	else 
		return false;
}

function add_command_parameter($service_id, $parameter) {
	
	$query = "INSERT INTO nagios_services_check_command_parameters (service_id, parameter) VALUES ('$service_id', '${parameter['parameter']}')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function add_service_template_command_parameter($service_template_id, $parameter) {
	
	$query = "INSERT INTO nagios_services_check_command_parameters (service_template_id, parameter) VALUES ('$service_template_id', '${parameter['parameter']}')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function add_host_template_dependency($host_template_id, $target_host_id) {
	$query = "INSERT INTO nagios_dependencies (host_template_id, target_host_id) VALUES ('$host_template_id', '$target_host_id')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}


function add_host_template_escalation($host_template_id, $escalation_description) {
	$query = "INSERT INTO nagios_escalations (host_template_id, escalation_description) VALUES ('$host_template_id', '$escalation_description')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function add_service_template_escalation($service_template_id, $escalation_description) {
	$query = "INSERT INTO nagios_escalations (service_template_id, escalation_description) VALUES ('$service_template_id', '$escalation_description')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function add_service_escalation($service_id, $escalation_description) {
	$query = "INSERT INTO nagios_escalations (service_id, escalation_description) VALUES ('$service_id', '$escalation_description')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function add_host_escalation($host_id, $escalation_description) {
	$query = "INSERT INTO nagios_escalations (host_id, escalation_description) VALUES ('$host_id', '$escalation_description')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function add_host_dependency($host_id, $target_host_id) {
	$query = "INSERT INTO nagios_dependencies (host_id, target_host_id) VALUES ('$host_id', '$target_host_id')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function add_service_dependency($service_id, $target_host_id, $target_service_id) {
	$query = "INSERT INTO nagios_dependencies (service_id, target_host_id, target_service_id) VALUES ('$service_id', '$target_host_id', '$target_service_id')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function add_service_template_dependency($service_template_id, $target_service_id) {
	$query = "INSERT INTO nagios_dependencies (service_template_id, target_service_id) VALUES ('$service_template_id', '$target_service_id')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}


function add_contact_address($contact_id, $address) {
	
	$query = "INSERT INTO nagios_contact_addresses (contact_id, address) VALUES ('$contact_id', '${address['address']}')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function link_host_service($host_id, $service_id) {
	
	$query = "INSERT INTO nagios_host_services (host_id, service_id) VALUES ('$host_id', '${service_id}')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function link_hostgroup_service($hostgroup_id, $service_id) {
	
	$query = "INSERT INTO nagios_hostgroup_services (hostgroup_id, service_id) VALUES ('$hostgroup_id', '${service_id}')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function add_host($hostinfo) {
	
	$query = "INSERT INTO nagios_hosts (";
	$query .= implode(", ", array_keys($hostinfo));
   	$query .= ") VALUES ('";

  	$query .= implode("', '", array_values($hostinfo));
   	$query .= "')";
	$result = $this->dbConnection->Execute($query);
	if($result) {
		$tempID = $this->return_host_id_by_name($hostinfo['host_name']);
		$query = "INSERT INTO nagios_hosts_extended_info (host_id) VALUES ('".$tempID."')";
		$this->dbConnection->Execute($query);
		return true;
	}
	else 
		return false;
}

function add_host_template($templateInfo) {
	$query = "INSERT INTO nagios_host_templates (";
	$query .= implode(", ", array_keys($templateInfo));
   	$query .= ") VALUES ('";

  	$query .= implode("', '", array_values($templateInfo));
   	$query .= "')";
	$result = $this->dbConnection->Execute($query);
	if($result) {
		$tempID = $this->return_host_template_id_by_name($templateInfo['template_name']);
		$query = "INSERT INTO nagios_host_template_extended_info (host_template_id) VALUES ('".$tempID."')";
		$this->dbConnection->Execute($query);
		return true;
	}
	else 
		return false;
}

function add_service_template($templateInfo) {
	$query = "INSERT INTO nagios_service_templates (";
	$query .= implode(", ", array_keys($templateInfo));
   	$query .= ") VALUES ('";

  	$query .= implode("', '", array_values($templateInfo));
   	$query .= "')";
	$result = $this->dbConnection->Execute($query);
	if($result) {
		$tempID = $this->return_service_template_id_by_name($templateInfo['template_name']);
		$query = "INSERT INTO nagios_service_template_extended_info (service_template_id) VALUES ('".$tempID."')";
		$this->dbConnection->Execute($query);
		return true;
	}
	else 
		return false;
}

function add_service($serviceinfo) {
	$query = "INSERT INTO nagios_services (";
	$query .= implode(", ", array_keys($serviceinfo));
   	$query .= ") VALUES ('";
  	$query .= implode("', '", array_values($serviceinfo));
   	$query .= "')";
   	$result = $this->dbConnection->Execute($query);
	if($result) {
		if(isset($serviceinfo['host_template_id']))
			$tempID = $this->return_service_id_by_host_template_and_description($serviceinfo['host_template_id'], $serviceinfo['service_description']);
		elseif(isset($serviceinfo['host_id']))
			$tempID = $this->return_service_id_by_host_and_description($serviceinfo['host_id'], $serviceinfo['service_description']);
		else
			$tempID = $this->return_service_id_by_hostgroup_and_description($serviceinfo['hostgroup_id'], $serviceinfo['service_description']);
		$query = "INSERT INTO nagios_services_extended_info (service_id) VALUES ('".$tempID."')";
		$this->dbConnection->Execute($query);
		return true;
	}
	else {
		return false;
	}
}

function modify_command($command_id, $command) {
	$query = "SELECT * FROM nagios_commands WHERE command_id = '$command_id'";
	$result = $this->dbConnection->Execute($query);
	unset($command['old_name']);
	$query = $this->dbConnection->GetUpdateSQL($result,$command,1);
	$result = $this->dbConnection->Execute($query);
}

function modify_contact($contact_id, $contact) {	
	$query = "SELECT * FROM nagios_contacts WHERE contact_id = '".$contact['contact_id']."'";
	$result = $this->dbConnection->Execute($query);
	unset($command['old_name']);
	$query = $this->dbConnection->GetUpdateSQL($result,$contact,1);
	$result = $this->dbConnection->Execute($query);
}

function modify_contactgroup($contactgroup_id, $contactgroup) {
	$query = "SELECT * FROM nagios_contactgroups WHERE contactgroup_id = '".$contactgroup_id."'";
	$result = $this->dbConnection->Execute($query);
	unset($command['old_name']);
	$query = $this->dbConnection->GetUpdateSQL($result,$contactgroup,1);
	$result = $this->dbConnection->Execute($query);
}

function modify_hostgroup($hostgroup_id, $hostgroup) {	
	$query = "SELECT * FROM nagios_hostgroups WHERE hostgroup_id = '".$hostgroup_id."'";
	$result = $this->dbConnection->Execute($query);
	unset($hostgroup['old_name']);
	$query = $this->dbConnection->GetUpdateSQL($result,$hostgroup,1);
	$result = $this->dbConnection->Execute($query);
}

function modify_servicegroup($servicegroup_id, $servicegroup) {
		
	$query = "SELECT * FROM nagios_servicegroups WHERE servicegroup_id = '".$servicegroup_id."'";
	$result = $this->dbConnection->Execute($query);
	unset($servicegroup['old_name']);
	$query = $this->dbConnection->GetUpdateSQL($result,$servicegroup,1);
	$result = $this->dbConnection->Execute($query);
}

function modify_period($period) {
		
	$query = "SELECT * FROM nagios_timeperiods WHERE timeperiod_id = '".$period['timeperiod_id']."'";
	$result = $this->dbConnection->Execute($query);
	unset($period['old_name']);
	$query = $this->dbConnection->GetUpdateSQL($result,$period,1);
	$result = $this->dbConnection->Execute($query);
}

function modify_host($host) {
		
	$query = "SELECT * FROM nagios_hosts WHERE host_id = '".$host['host_id']."'";
	$result = $this->dbConnection->Execute($query);
	unset($host['old_name']);	// Just in case
	$query = $this->dbConnection->GetUpdateSQL($result,$host, 1);
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function modify_host_template($host_template) {
		
	$query = "SELECT * FROM nagios_host_templates WHERE host_template_id = '".$host_template['host_template_id']."'";
	$result = $this->dbConnection->Execute($query);
	unset($host['old_name']);	// Just in case
	$query = $this->dbConnection->GetUpdateSQL($result,$host_template, 1);
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function modify_service_template($service_template) {
		
	$query = "SELECT * FROM nagios_service_templates WHERE service_template_id = '".$service_template['service_template_id']."'";
	$result = $this->dbConnection->Execute($query);
	unset($host['old_name']);	// Just in case
	$query = $this->dbConnection->GetUpdateSQL($result,$service_template, 1);
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}


function modify_service($service) {
	
	if($service['check_command'] != '')
		unset($service['check_command_id']);
	$query = "SELECT * FROM nagios_services WHERE service_id = '".$service['service_id']."'";
	$result = $this->dbConnection->Execute($query);
	$query = $this->dbConnection->GetUpdateSQL($result,$service,1);
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function modify_dependency($dependency) {
	$query = "SELECT * FROM nagios_dependencies WHERE dependency_id = '".$dependency['dependency_id']."'";
	$result = $this->dbConnection->Execute($query);
	$query = $this->dbConnection->GetUpdateSQL($result,$dependency,1);
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function modify_escalation($escalation) {
	$query = "SELECT * FROM nagios_escalations WHERE escalation_id = '".$escalation['escalation_id']."'";
	$result = $this->dbConnection->Execute($query);
	$query = $this->dbConnection->GetUpdateSQL($result,$escalation,1);
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function delete_command($command_id) {
	
	$query = "DELETE FROM nagios_commands WHERE command_id = '$command_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_dependency($dependency_id) {
	
	$query = "DELETE FROM nagios_dependencies WHERE dependency_id = '$dependency_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_escalation($escalation_id) {
	$query = "DELETE FROM nagios_escalations WHERE escalation_id = '$escalation_id'";
	$result = $this->dbConnection->Execute($query);
	$query = "DELETE FROM nagios_escalation_contactgroups WHERE escalation_id = '$escalation_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_period($timeperiod_id) {
	
	$query = "DELETE FROM nagios_timeperiods WHERE timeperiod_id = '$timeperiod_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_contact_notification_command($command_id) {
	
	$query = "DELETE FROM nagios_contacts_notification_commands WHERE contact_notification_command_id = '$command_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_contactgroup_member($contactgroup_id, $contact_id) {
	
	$query = "DELETE FROM nagios_contactgroup_membership WHERE contactgroup_id = '$contactgroup_id' AND contact_id = '$contact_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_service($service_id) {
	$query = "DELETE FROM nagios_hostgroup_services WHERE service_id = '$service_id'";
	$result = $this->dbConnection->Execute($query);
	$query = "DELETE FROM nagios_services WHERE service_id = '$service_id'";
	$result = $this->dbConnection->Execute($query);
	$query = "DELETE FROM nagios_services_check_command_parameters WHERE service_id = '$service_id'";
	$result = $this->dbConnection->Execute($query);
	$query = "DELETE FROM nagios_services_extended_info WHERE service_id = '$service_id'";
	$result = $this->dbConnection->Execute($query);
}

function unlink_host_service($host_id, $service_id) {
	
	$query = "DELETE FROM nagios_host_services WHERE host_id = '$host_id' AND service_id = '$service_id'";
	$result = $this->dbConnection->Execute($query);
}

function unlink_hostgroup_service($hostgroup_id, $service_id) {
	
	$query = "DELETE FROM nagios_hostgroup_services WHERE hostgroup_id = '$hostgroup_id' AND service_id = '$service_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_checkcommand_parameter($parameter_id) {
	
	$query = "DELETE FROM nagios_services_check_command_parameters WHERE checkcommandparameter_id = '$parameter_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_contact_address($address_id) {
	
	$query = "DELETE FROM nagios_contact_addresses WHERE contactaddress_id = '$address_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_hostgroup_member($hostgroup_id, $host_id) {
	
	$query = "DELETE FROM nagios_hostgroup_membership WHERE hostgroup_id = '$hostgroup_id' AND host_id = '$host_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_hostgroup_template_member($hostgroup_id, $host_template_id) {
	
	$query = "DELETE FROM nagios_hostgroup_template_membership WHERE hostgroup_id = '$hostgroup_id' AND host_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);
}


function delete_all_data() {
	$this->dbConnection->Execute("DELETE FROM nagios_cgi");
	$this->dbConnection->Execute("DELETE FROM nagios_commands");
	$this->dbConnection->Execute("DELETE FROM nagios_contact_addresses");
	$this->dbConnection->Execute("DELETE FROM nagios_contactgroup_membership");
	$this->dbConnection->Execute("DELETE FROM nagios_contactgroups");
	$this->dbConnection->Execute("DELETE FROM nagios_contacts");
	$this->dbConnection->Execute("DELETE FROM nagios_contacts_notification_commands");
	$this->dbConnection->Execute("DELETE FROM nagios_dependencies");
	$this->dbConnection->Execute("DELETE FROM nagios_escalation_contactgroups");
	$this->dbConnection->Execute("DELETE FROM nagios_escalations");
	$this->dbConnection->Execute("DELETE FROM nagios_host_contactgroups");
	$this->dbConnection->Execute("DELETE FROM nagios_host_services");
	$this->dbConnection->Execute("DELETE FROM nagios_host_template_contactgroups");
	$this->dbConnection->Execute("DELETE FROM nagios_host_template_extended_info");
	$this->dbConnection->Execute("DELETE FROM nagios_host_templates");
	$this->dbConnection->Execute("DELETE FROM nagios_hostgroup_contactgroups");
	$this->dbConnection->Execute("DELETE FROM nagios_hostgroup_membership");
	$this->dbConnection->Execute("DELETE FROM nagios_hostgroup_template_membership");
	$this->dbConnection->Execute("DELETE FROM nagios_hostgroups");
	$this->dbConnection->Execute("DELETE FROM nagios_hosts");
	$this->dbConnection->Execute("DELETE FROM nagios_hosts_extended_info");
	$this->dbConnection->Execute("DELETE FROM nagios_main");
	$this->dbConnection->Execute("DELETE FROM nagios_resources");
	$this->dbConnection->Execute("DELETE FROM nagios_service_contactgroups");
	$this->dbConnection->Execute("DELETE FROM nagios_service_servicegroups");
	$this->dbConnection->Execute("DELETE FROM nagios_service_template_contactgroups");
	$this->dbConnection->Execute("DELETE FROM nagios_service_template_extended_info");
	$this->dbConnection->Execute("DELETE FROM nagios_service_template_servicegroups");
	$this->dbConnection->Execute("DELETE FROM nagios_service_templates");
	$this->dbConnection->Execute("DELETE FROM nagios_servicegroups");
	$this->dbConnection->Execute("DELETE FROM nagios_services");
	$this->dbConnection->Execute("DELETE FROM nagios_services_check_command_parameters");
	$this->dbConnection->Execute("DELETE FROM nagios_services_extended_info");
	$this->dbConnection->Execute("DELETE FROM nagios_timeperiods");
	$this->dbConnection->Execute("INSERT INTO nagios_main(config_dir) VALUES(NULL)");
	$this->dbConnection->Execute("INSERT INTO nagios_cgi(physical_html_path) VALUES(NULL)");
}
	
function delete_hostgroup_contactgroup($hostgroup_id, $contactgroup_id) {
	
	$query = "DELETE FROM nagios_hostgroup_contactgroups WHERE hostgroup_id = '$hostgroup_id' AND contactgroup_id = '$contactgroup_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_host_contactgroup($host_id, $contactgroup_id) {
	
	$query = "DELETE FROM nagios_host_contactgroups WHERE host_id = '$host_id' AND contactgroup_id = '$contactgroup_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_host_template_contactgroup($host_template_id, $contactgroup_id) {
	
	$query = "DELETE FROM nagios_host_template_contactgroups WHERE host_template_id = '$host_template_id' AND contactgroup_id = '$contactgroup_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_service_template_contactgroup($service_template_id, $contactgroup_id) {
	
	$query = "DELETE FROM nagios_service_template_contactgroups WHERE service_template_id = '$service_template_id' AND contactgroup_id = '$contactgroup_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_service_template_servicegroup($service_template_id, $servicegroup_id) {
	
	$query = "DELETE FROM nagios_service_template_servicegroups WHERE service_template_id = '$service_template_id' AND servicegroup_id = '$servicegroup_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_service_contactgroup($service_id, $contactgroup_id) {
	
	$query = "DELETE FROM nagios_service_contactgroups WHERE service_id = '$service_id' AND contactgroup_id = '$contactgroup_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_escalation_contactgroup($escalation_id, $contactgroup_id) {
	
	$query = "DELETE FROM nagios_escalation_contactgroups WHERE escalation_id = '$escalation_id' AND contactgroup_id = '$contactgroup_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_service_servicegroup($service_id, $servicegroup_id) {
	
	$query = "DELETE FROM nagios_service_servicegroups WHERE service_id = '$service_id' AND servicegroup_id = '$servicegroup_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_contact($contact_id) {
	
	$query = "DELETE FROM nagios_contactgroup_membership WHERE contact_id = '$contact_id'";
	$result = $this->dbConnection->Execute($query);
	$query = "DELETE FROM nagios_contacts WHERE contact_id = '$contact_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_host($host_id) {
	
	$query = "DELETE FROM nagios_hostgroup_membership WHERE host_id = '$host_id'";
	// Get a list of services which belong to this host
	$query = "SELECT service_id FROM nagios_services WHERE host_id = '$host_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$query = "DELETE FROM nagios_services_check_command_parameters WHERE service_id = '".$result->fields['service_id']."'";
		$subResult = $this->dbConnection->Execute($query);
		$serviceIDs[] = $result->fields['service_id'];
		$result->MoveNext();
	}
	$numOfServices = count($serviceIDs);
	for($counter = 0; $counter < $numOfServices; $counter++) {
		$query = "DELETE FROM nagios_services WHERE service_id = '${serviceIDs[$counter]}'";
		$result = $this->dbConnection->Execute($query);
	}
	// Get parent id
	$query = "SELECT parents FROM nagios_hosts WHERE host_id = '$host_id'";
	$result = $this->dbConnection->Execute($query);
	$tempParentID = $result->fields['parents'];
	$query = "UPDATE nagios_hosts SET parents = '$tempParentID' WHERE parents = '$host_id'";
	$result = $this->dbConnection->Execute($query);
	$query = "DELETE FROM nagios_hosts WHERE host_id = '$host_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_host_template($host_template_id) {
	
	$query = "DELETE FROM nagios_hostgroup_template_membership WHERE host_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);
	$query = "DELETE FROM nagios_host_template_contactgroups WHERE host_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);

	// TODO: Get list of services for this host template and remove them
	
	/*
	// Get a list of services which belong to this host
	$query = "SELECT service_id FROM nagios_services WHERE host_id = '$host_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$query = "DELETE FROM nagios_services_check_command_parameters WHERE service_id = '".$result->fields['service_id']."'";
		$subResult = $this->dbConnection->Execute($query);
		$serviceIDs[] = $result->fields['service_id'];
		$result->MoveNext();
	}
	$numOfServices = count($serviceIDs);
	for($counter = 0; $counter < $numOfServices; $counter++) {
		$query = "DELETE FROM nagios_services WHERE service_id = '${serviceIDs[$counter]}'";
		$result = $this->dbConnection->Execute($query);
	}
	
	// Get parent id
	$query = "SELECT parents FROM nagios_hosts WHERE host_id = '$host_id'";
	$result = $this->dbConnection->Execute($query);
	$tempParentID = $result->fields['parents'];
	$query = "UPDATE nagios_hosts SET parents = '$tempParentID' WHERE parents = '$host_id'";
	$result = $this->dbConnection->Execute($query);
	*/
	// Let's get a list of dependent host templates
	$this->get_host_template_info($host_template_id, $tempTemplateInfo);
	unset($tempTemplateInfo['host_template_id']);
	unset($tempTemplateInfo['template_name']);
	unset($tempTemplateInfo['template_description']);
	
	$query = "SELECT * FROM nagios_host_templates WHERE use_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);
	while (!$result->EOF)
	{
		$dependentTemplate = $result->fields;
		// Field checks
		foreach($tempTemplateInfo as $key=>$value) {
			if(isset($tempTemplateInfo[$key]) && !isset($dependentTemplate[$key]))
				$dependentTemplate[$key] = $value;
		}
		// $dependentTemplate['use_template_id'] = NULL;
		$this->modify_host_template($dependentTemplate);
		$result->MoveNext();
	}

	// Extended info
	$this->get_host_template_extended_info($host_template_id, $tempTemplateInfo);
	unset($tempTemplateInfo['host_template_id']);
	
	$query = "SELECT * FROM nagios_host_templates WHERE use_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);
	while(!$result->EOF) {
		$query = "SELECT * FROM nagios_host_template_extended_info WHERE host_template_id = '".$result->fields['host_template_id']."'";
		$tempResult = $this->dbConnection->Execute($query);
		$dependentTemplateExtended = $tempResult->fields;
		// Field checks
		foreach($tempTemplateInfo as $key=>$value) {
			if(isset($tempTemplateInfo[$key]) && !isset($dependentTemplate[$key]))
				$dependentTemplate[$key] = $value;
		}
		$this->modify_host_template_extended($dependentTemplateExtended['host_template_id'], $dependentTemplate);
		$result->MoveNext();		
	}
	$query = "DELETE FROM nagios_host_template_extended_info WHERE host_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);	
	$query = "DELETE FROM nagios_host_templates WHERE host_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);
	
	// Remove use_template_id from dependent templates
	$query = "UPDATE nagios_host_templates SET use_template_id = NULL WHERE use_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_service_template($service_template_id) {	
	$query = "DELETE FROM nagios_service_template_contactgroups WHERE service_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	$query = "DELETE FROM nagios_service_template_servicegroups WHERE service_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);

	// Let's get a list of dependent service templates and services
	$this->get_service_template_info($service_template_id, $tempTemplateInfo);
	unset($tempTemplateInfo['service_template_id']);
	unset($tempTemplateInfo['template_name']);
	unset($tempTemplateInfo['template_description']);
	$query = "SELECT * FROM nagios_service_templates WHERE use_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	while (!$result->EOF)
	{
		$dependentTemplate = $result->fields;
		// Field checks
		foreach($tempTemplateInfo as $key=>$value) {
			if(isset($tempTemplateInfo[$key]) && !isset($dependentTemplate[$key]))
				$dependentTemplate[$key] = $value;
		}
		// $dependentTemplate['use_template_id'] = NULL;
		$this->modify_service_template($dependentTemplate);
		$result->MoveNext();
	}
	$query = "SELECT * FROM nagios_services WHERE use_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	while (!$result->EOF)
	{
		$dependentTemplate = $result->fields;
		// Field checks
		foreach($tempTemplateInfo as $key=>$value) {
			if(isset($tempTemplateInfo[$key]) && !isset($dependentTemplate[$key]))
				$dependentTemplate[$key] = $value;
		}
		// $dependentTemplate['use_template_id'] = NULL;
		$this->modify_service($dependentTemplate);
		$result->MoveNext();
	}

	// Extended info
	$this->get_service_template_extended_info($service_template_id, $tempTemplateInfo);
	unset($tempTemplateInfo['service_template_id']);
	$query = "SELECT * FROM nagios_service_templates WHERE use_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	while(!$result->EOF) {
		$query = "SELECT * FROM nagios_service_template_extended_info WHERE service_template_id = '".$result->fields['service_template_id']."'";
		$tempResult = $this->dbConnection->Execute($query);
		$dependentTemplateExtended = $tempResult->fields;
		// Field checks
		foreach($tempTemplateInfo as $key=>$value) {
			if(isset($tempTemplateInfo[$key]) && !isset($dependentTemplateExtended[$key]))
				$dependentTemplateExtended[$key] = $value;
		}
		$this->modify_service_template_extended($dependentTemplateExtended['service_template_id'], $dependentTemplateExtended);
		$result->MoveNext();		
	}
	$query = "SELECT * FROM nagios_service_templates WHERE use_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	while(!$result->EOF) {
		$query = "SELECT * FROM nagios_service_extended_info WHERE service_id = '".$result->fields['service_id']."'";
		$tempResult = $this->dbConnection->Execute($query);
		$dependentServiceExtended = $tempResult->fields;
		// Field checks
		foreach($tempTemplateInfo as $key=>$value) {
			if(isset($tempTemplateInfo[$key]) && !isset($dependentServiceExtended[$key]))
				$dependentServiceExtended[$key] = $value;
		}
		$this->modify_service_extended($dependentServiceExtended['service_id'], $dependentServiceExtended);
		$result->MoveNext();		
	}
	
	
	$query = "DELETE FROM nagios_service_template_extended_info WHERE service_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);	
	$query = "DELETE FROM nagios_service_templates WHERE service_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	
	// Remove use_template_id from dependent templates
	$query = "UPDATE nagios_service_templates SET use_template_id = NULL WHERE use_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	// Remove use_template_id from dependent services
	$query = "UPDATE nagios_services SET use_template_id = NULL WHERE use_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
}
	
function delete_hostgroup($hostgroup_id) {
	
	$query = "DELETE FROM nagios_hostgroup_contactgroups WHERE hostgroup_id = '$hostgroup_id'";
	$result = $this->dbConnection->Execute($query);
	$query = "DELETE FROM nagios_hostgroup_membership WHERE hostgroup_id = '$hostgroup_id'";
	$result = $this->dbConnection->Execute($query);
	$query = "DELETE FROM nagios_hostgroups WHERE hostgroup_id = '$hostgroup_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_servicegroup($servicegroup_id) {
	
	$query = "DELETE FROM nagios_service_servicegroups WHERE servicegroup_id = '$servicegroup_id'";
	$result = $this->dbConnection->Execute($query);
	$query = "DELETE FROM nagios_servicegroups WHERE servicegroup_id = '$servicegroup_id'";
	$result = $this->dbConnection->Execute($query);
}

function delete_contactgroup($contactgroup_id) {
	
	$query = "DELETE FROM nagios_contactgroup_membership WHERE contactgroup_id = '$contactgroup_id'";
	$result = $this->dbConnection->Execute($query);
	$query = "DELETE FROM nagios_contactgroups WHERE contactgroup_id = '$contactgroup_id'";
	$result = $this->dbConnection->Execute($query);	
}
	
	
	
function get_contact_membership_list($contact_id, &$group_list) {
	
	$query = "SELECT * FROM nagios_contactgroup_membership WHERE contact_id = '$contact_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$group_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function get_host_services_list($host_id, &$service_list) {
	
	$query = "SELECT service_id, host_id FROM nagios_services WHERE host_id = '$host_id'";
	$result = $this->dbConnection->Execute($query);
	print_r($service_list);
	while (! $result->EOF)
	{
		$service_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function get_host_template_services_list($host_template_id, &$service_list) {
	
	$query = "SELECT service_id, host_template_id FROM nagios_services WHERE host_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);
	print_r($service_list);
	while (! $result->EOF)
	{
		$service_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function get_hostgroup_services_list($hostgroup_id, &$service_list) {
	
	$query = "SELECT service_id FROM nagios_services WHERE hostgroup_id = '$hostgroup_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$service_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function get_service_check_command_parameters($service_id, &$parameter_list) {
	$parameter_list = NULL;
	
	$query = "SELECT * FROM nagios_services_check_command_parameters WHERE service_id = '$service_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$parameter_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function get_service_template_check_command_parameters($service_template_id, &$parameter_list) {
	$parameter_list = NULL;
	
	$query = "SELECT * FROM nagios_services_check_command_parameters WHERE service_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$parameter_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function get_contact_addresses($contact_id, &$address_list) {
	$address_list = NULL;
	
	$query = "SELECT * FROM nagios_contact_addresses WHERE contact_id = '$contact_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$address_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}	

function get_host_membership_list($host_id, &$group_list) {
	
	$query = "SELECT * FROM nagios_hostgroup_membership WHERE host_id = '$host_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$group_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function get_host_template_membership_list($host_template_id, &$group_list) {
	
	$query = "SELECT * FROM nagios_hostgroup_template_membership WHERE host_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$group_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function get_service_contactgroups($service_id, &$group_list) {
	$group_list = NULL;
	
	$query = "SELECT * FROM nagios_service_contactgroups WHERE service_id = '$service_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$group_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function get_service_servicegroups($service_id, &$group_list) {
	$group_list = NULL;
	
	$query = "SELECT * FROM nagios_service_servicegroups WHERE service_id = '$service_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$group_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}	

function get_host_nav_info($host_id, &$hostinfo) {
	
	$query = "SELECT host_id, parents, host_name FROM nagios_hosts WHERE host_id = '$host_id'";
	$result = $this->dbConnection->Execute($query);
	$hostinfo = $result->fields;
}

function get_host_info($host_id, &$hostinfo) {
	
	$query = "SELECT * FROM nagios_hosts WHERE host_id = '$host_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$hostinfo = $result->fields;
		return true;
	}
	else {
		return false;
	}
}

function get_dependency($dependency_id, &$dependency_info) {
	
	$query = "SELECT * FROM nagios_dependencies WHERE dependency_id = '$dependency_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$dependency_info = $result->fields;
		return true;
	}
	else {
		return false;
	}
}

function get_escalation($escalation_id, &$escalation_info) {
	
	$query = "SELECT * FROM nagios_escalations WHERE escalation_id = '$escalation_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$escalation_info = $result->fields;
		return true;
	}
	else {
		return false;
	}
}



function get_host_template_info($host_template_id, &$hosttemplateinfo) {
	$query = "SELECT * FROM nagios_host_templates WHERE host_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$hosttemplateinfo = $result->fields;
		return true;
	}
	else {
		return false;
	}
}

function get_service_template_info($service_template_id, &$servicetemplateinfo) {
	$query = "SELECT * FROM nagios_service_templates WHERE service_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$servicetemplateinfo = $result->fields;
		return true;
	}
	else {
		return false;
	}
}

// Function to recursively get the hosts affected by a template
function get_hosts_affected_by_host_template($host_template_id, &$affectedHosts) {
	$query = "SELECT host_template_id FROM nagios_host_templates WHERE use_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		// Then there are additional templates dependent upon our template, let's call with them.
		while(! $result->EOF) {
			$this->get_hosts_affected_by_host_template($result->fields['host_template_id'], $affectedHosts);
			$result->MoveNext();
		}
	}
	// Okay, we're at a leaf, let's get all the hosts affected by this template
	$query = "SELECT host_id FROM nagios_hosts WHERE use_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->affected_Rows()) {
		while(! $result->EOF) {
			if(!is_array($affectedHosts) || !in_array($result->fields['host_id'], $affectedHosts)) {
				$affectedHosts[] = $result->fields['host_id'];
			}
			$result->MoveNext();
		}
	}
}

// Function to recursively get the services affected by a template
function get_services_affected_by_service_template($service_template_id, &$affectedServices) {
	$query = "SELECT service_template_id FROM nagios_service_templates WHERE use_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		// Then there are additional templates dependent upon our template, let's call with them.
		while(! $result->EOF) {
			$this->get_services_affected_by_service_template($result->fields['service_template_id'], $affectedServices);
			$result->MoveNext();
		}
	}
	// Okay, we're at a leaf, let's get all the hosts affected by this template
	$query = "SELECT service_id FROM nagios_services WHERE use_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->affected_Rows()) {
		while(! $result->EOF) {
			if(!is_array($affectedServices) || !in_array($result->fields['service_id'], $affectedServices)) {
				$affectedServices[] = $result->fields['service_id'];
			}
			$result->MoveNext();
		}
	}
}


// Function recursively gets the inherited template values, given a template
function get_inherited_host_template_values($host_template_id, &$hosttemplateinfo, &$hosttemplateinfoSources) {
	$query = "SELECT * FROM nagios_host_templates WHERE host_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$tempTemplateInfo = $result->fields;
		if(isset($tempTemplateInfo['use_template_id'])) {
			$this->get_inherited_host_template_values($tempTemplateInfo['use_template_id'], $hosttemplateinfo, $hosttemplateinfoSources);
		}
		$tempTemplateName = $tempTemplateInfo['template_name'];		
		unset($tempTemplateInfo['host_template_id']);
		unset($tempTemplateInfo['use_template_id']);
		unset($tempTemplateInfo['template_name']);
		unset($tempTemplateInfo['template_description']);		
		foreach($tempTemplateInfo as $key=>$value) {
			if(isset($tempTemplateInfo[$key])) {
				$hosttemplateinfo[$key] = $value;
				$hosttemplateinfoSources[$key] = $tempTemplateName;
			}
		}
		return true;
	}
	else {
		return false;	// Should never really get here
	}
}

// Function recursively gets the inherited template values, given a template
function get_inherited_service_template_values($service_template_id, &$servicetemplateinfo, &$servicetemplateinfoSources) {
	$query = "SELECT * FROM nagios_service_templates WHERE service_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$tempTemplateInfo = $result->fields;
		if(isset($tempTemplateInfo['use_template_id'])) {
			$this->get_inherited_service_template_values($tempTemplateInfo['use_template_id'], $servicetemplateinfo, $servicetemplateinfoSources);
		}
		$tempTemplateName = $tempTemplateInfo['template_name'];		
		unset($tempTemplateInfo['service_template_id']);
		unset($tempTemplateInfo['use_template_id']);
		unset($tempTemplateInfo['template_name']);
		unset($tempTemplateInfo['template_description']);		
		foreach($tempTemplateInfo as $key=>$value) {
			if(isset($tempTemplateInfo[$key])) {
				$servicetemplateinfo[$key] = $value;
				$servicetemplateinfoSources[$key] = $tempTemplateName;
			}
		}
		return true;
	}
	else {
		return false;	// Should never really get here
	}
}

// Function recursively gets the inherited template values, given a template
function get_inherited_service_template_extended_values($service_template_id, &$servicetemplateinfo, &$servicetemplateinfoSources) {
	$query = "SELECT * FROM nagios_service_templates WHERE service_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$tempTemplateInfo = $result->fields;
		if(isset($tempTemplateInfo['use_template_id'])) {
			$this->get_inherited_service_template_extended_values($tempTemplateInfo['use_template_id'], $servicetemplateinfo, $servicetemplateinfoSources);
		}
		$tempTemplateName = $tempTemplateInfo['template_name'];		
		$query = "SELECT * FROM nagios_service_template_extended_info WHERE service_template_id = '$service_template_id'";
		$result = $this->dbConnection->Execute($query);
		$tempTemplateInfo = $result->fields;
		unset($tempTemplateInfo['service_template_id']);		
		foreach($tempTemplateInfo as $key=>$value) {
			if(isset($tempTemplateInfo[$key])) {
				$servicetemplateinfo[$key] = $value;
				$servicetemplateinfoSources[$key] = $tempTemplateName;
			}
		}
		return true;
	}
	else {
		return false;	// Should never really get here
	}
}

// Function recursively gets the inherited template values, given a template
function get_inherited_host_template_extended_values($host_template_id, &$hosttemplateinfo, &$hosttemplateinfoSources) {
	$query = "SELECT * FROM nagios_host_templates WHERE host_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$tempTemplateInfo = $result->fields;
		if(isset($tempTemplateInfo['use_template_id'])) {
			$this->get_inherited_host_template_extended_values($tempTemplateInfo['use_template_id'], $hosttemplateinfo, $hosttemplateinfoSources);
		}
		$tempTemplateName = $tempTemplateInfo['template_name'];		
		$query = "SELECT * FROM nagios_host_template_extended_info WHERE host_template_id = '$host_template_id'";
		$result = $this->dbConnection->Execute($query);
		$tempTemplateInfo = $result->fields;
		unset($tempTemplateInfo['host_template_id']);		
		foreach($tempTemplateInfo as $key=>$value) {
			if(isset($tempTemplateInfo[$key])) {
				$hosttemplateinfo[$key] = $value;
				$hosttemplateinfoSources[$key] = $tempTemplateName;
			}
		}
		return true;
	}
	else {
		return false;	// Should never really get here
	}
}

// Function recursively gets the inherited template values, given a template
function get_host_template_inherited_contactgroups_list($host_template_id, &$groupList) {
	$query = "SELECT * FROM nagios_host_templates WHERE host_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$tempTemplateInfo = $result->fields;
		if(isset($tempTemplateInfo['use_template_id'])) {
			$this->get_host_template_inherited_contactgroups_list($tempTemplateInfo['use_template_id'], $groupList);
		}
		$tempTemplateName = $tempTemplateInfo['template_name'];		
		$query = "SELECT contactgroup_id FROM nagios_host_template_contactgroups WHERE host_template_id = '$host_template_id'";
		$result = $this->dbConnection->Execute($query);
		// While loop
		while (! $result->EOF)
		{
			$tempContactGroups[] = $result->fields['contactgroup_id'];
			$result->MoveNext();
		}
		if(count($tempContactGroups)) {
			foreach($tempContactGroups as $groupID) {
				if(!is_array($groupList) || !in_array($groupID, $groupList)) {
					$groupList[$groupID] = $groupID;
				}
			}
		}
		return true;
	}
	else {
		return false;	// Should never really get here
	}
}

// Function recursively gets the inherited template values, given a template
function get_host_template_inherited_escalations_list($host_template_id, &$escalationList) {
	$query = "SELECT * FROM nagios_host_templates WHERE host_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$tempTemplateInfo = $result->fields;
		if(isset($tempTemplateInfo['use_template_id'])) {
			$this->get_host_template_inherited_escalations_list($tempTemplateInfo['use_template_id'], $escalationList);
		}
		$tempTemplateName = $tempTemplateInfo['template_name'];		
		$query = "SELECT escalation_id FROM nagios_escalations WHERE host_template_id = '$host_template_id'";
		$result = $this->dbConnection->Execute($query);
		// While loop
		while (! $result->EOF)
		{
			$tempEscalations[] = $result->fields['escalation_id'];
			$result->MoveNext();
		}
		if(count($tempEscalations)) {
			foreach($tempEscalations as $escalation) {
				if(!is_array($escalationList) || !in_array($escalation, $escalationList)) {
					$escalationList[$escalation] = $escalation;
				}
			}
		}
		return true;
	}
	else {
		return false;	// Should never really get here
	}
}

// Function recursively gets the inherited template values, given a template
function get_service_template_inherited_commandparameter_list($service_template_id, &$parameterList) {
	$query = "SELECT * FROM nagios_service_templates WHERE service_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$tempTemplateInfo = $result->fields;
		if(isset($tempTemplateInfo['use_template_id'])) {
			$this->get_service_template_inherited_commandparameter_list($tempTemplateInfo['use_template_id'], $parameterList);
		}
		$tempTemplateName = $tempTemplateInfo['template_name'];		
		$query = "SELECT * FROM nagios_services_check_command_parameters WHERE service_template_id = '$service_template_id'";
		$result = $this->dbConnection->Execute($query);
		// While loop
		while (! $result->EOF)
		{
			$tempParameters[] = $result->fields;
			$result->MoveNext();
		}
		if(count($tempParameters)) {
			foreach($tempParameters as $parameter) {
					$parameterList[] = $parameter;
			}
		}
		return true;
	}
	else {
		return false;	// Should never really get here
	}
}


// Function recursively gets the inherited template values, given a template
function get_service_template_inherited_escalations_list($service_template_id, &$escalationList) {
	$query = "SELECT * FROM nagios_service_templates WHERE service_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$tempTemplateInfo = $result->fields;
		if(isset($tempTemplateInfo['use_template_id'])) {
			$this->get_service_template_inherited_escalations_list($tempTemplateInfo['use_template_id'], $escalationList);
		}
		$tempTemplateName = $tempTemplateInfo['template_name'];		
		$query = "SELECT escalation_id FROM nagios_escalations WHERE service_template_id = '$service_template_id'";
		$result = $this->dbConnection->Execute($query);
		// While loop
		while (! $result->EOF)
		{
			$tempEscalations[] = $result->fields['escalation_id'];
			$result->MoveNext();
		}
		if(count($tempEscalations)) {
			foreach($tempEscalations as $escalation) {
				if(!is_array($escalationList) || !in_array($escalation, $escalationList)) {
					$escalationList[$escalation] = $escalation;
				}
			}
		}
		return true;
	}
	else {
		return false;	// Should never really get here
	}
}

function get_host_template_inherited_hostgroups_list($host_template_id, &$groupList) {
	$query = "SELECT * FROM nagios_host_templates WHERE host_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$tempTemplateInfo = $result->fields;
		if(isset($tempTemplateInfo['use_template_id'])) {
			$this->get_host_template_inherited_hostgroups_list($tempTemplateInfo['use_template_id'], $groupList);
		}
		$tempTemplateName = $tempTemplateInfo['template_name'];		
		$query = "SELECT hostgroup_id FROM nagios_hostgroup_template_membership WHERE host_template_id = '$host_template_id'";
		$result = $this->dbConnection->Execute($query);
		// While loop
		while (! $result->EOF)
		{
			$tempHostGroups[] = $result->fields['hostgroup_id'];
			$result->MoveNext();
		}
		if(count($tempHostGroups)) {
			foreach($tempHostGroups as $groupID) {
				if(!is_array($groupList) || !in_array($groupID, $groupList)) {
					$groupList[$groupID] = $groupID;
				}
			}
		}
		return true;
	}
	else {
		return false;	// Should never really get here
	}
}

// Function recursively gets the inherited template values, given a template
function get_host_template_inherited_dependencies_list($host_template_id, &$dependencies_list) {
	$query = "SELECT * FROM nagios_host_templates WHERE host_template_id = '$host_template_id'";

	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$tempTemplateInfo = $result->fields;
		if(isset($tempTemplateInfo['use_template_id'])) {
			$this->get_host_template_inherited_dependencies_list($tempTemplateInfo['use_template_id'], $dependencies_list);
		}
		$tempTemplateName = $tempTemplateInfo['template_name'];		
		$query = "SELECT * FROM nagios_dependencies WHERE host_template_id = '$host_template_id' AND service_id IS NULL";
		$result = $this->dbConnection->Execute($query);
		// While loop
		while (! $result->EOF)
		{
			$tempDependencies[] = $result->fields;
			$result->MoveNext();
		}
		if(count($tempDependencies)) {
			foreach($tempDependencies as $dependency) {
				if(!is_array($dependencies_list) || !in_array($dependency['host_id'], $dependencies_list)) {
					$dependencies_list[$dependency['host_id']] = $dependency;
				}
			}
		}
		return true;
	}
	else {
		return false;	// Should never really get here
	}
}

// Function recursively gets the inherited template values, given a template
function get_service_template_inherited_dependencies_list($service_template_id, &$dependencies_list) {
	$query = "SELECT * FROM nagios_service_templates WHERE service_template_id = '$service_template_id'";

	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$tempTemplateInfo = $result->fields;
		if(isset($tempTemplateInfo['use_template_id'])) {
			$this->get_service_template_inherited_dependencies_list($tempTemplateInfo['use_template_id'], $dependencies_list);
		}
		$tempTemplateName = $tempTemplateInfo['template_name'];		
		$query = "SELECT * FROM nagios_dependencies WHERE service_template_id = '$service_template_id'";
		$result = $this->dbConnection->Execute($query);
		// While loop
		while (! $result->EOF)
		{
			$tempDependencies[] = $result->fields;
			$result->MoveNext();
		}
		if(count($tempDependencies)) {
			foreach($tempDependencies as $dependency) {
				if(!is_array($dependencies_list) || !in_array($dependency['target_service_id'], $dependencies_list)) {
					$dependencies_list[$dependency['target_service_id']] = $dependency;
				}
			}
		}
		return true;
	}
	else {
		return false;	// Should never really get here
	}
}



// Function recursively gets the inherited template values, given a template
function get_host_template_inherited_services_list($host_template_id, &$groupList) {
	$query = "SELECT * FROM nagios_host_templates WHERE host_template_id = '$host_template_id'";

	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$tempTemplateInfo = $result->fields;
		if(isset($tempTemplateInfo['use_template_id'])) {
			$this->get_host_template_inherited_services_list($tempTemplateInfo['use_template_id'], $groupList);
		}
		$tempTemplateName = $tempTemplateInfo['template_name'];		
		$query = "SELECT service_id, host_template_id, service_description FROM nagios_services WHERE host_template_id = '$host_template_id'";
		$result = $this->dbConnection->Execute($query);
		// While loop
		while (! $result->EOF)
		{
			$tempServices[] = $result->fields;
			$result->MoveNext();
		}
		if(count($tempServices)) {
			foreach($tempServices as $service) {
				if(!is_array($groupList) || !in_array($service['service_description'], $groupList)) {
					$groupList[$service['service_description']] = $service;
				}
			}
		}
		return true;
	}
	else {
		return false;	// Should never really get here
	}
}

// Function recursively gets the inherited template values, given a template
function get_service_template_inherited_contactgroups_list($service_template_id, &$groupList) {
	$query = "SELECT * FROM nagios_service_templates WHERE service_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$tempTemplateInfo = $result->fields;
		if(isset($tempTemplateInfo['use_template_id'])) {
			$this->get_service_template_inherited_contactgroups_list($tempTemplateInfo['use_template_id'], $groupList);
		}
		$tempTemplateName = $tempTemplateInfo['template_name'];		
		$query = "SELECT contactgroup_id FROM nagios_service_template_contactgroups WHERE service_template_id = '$service_template_id'";
		$result = $this->dbConnection->Execute($query);
		// While loop
		while (! $result->EOF)
		{
			$tempContactGroups[] = $result->fields['contactgroup_id'];
			$result->MoveNext();
		}
		if(count($tempContactGroups)) {
			foreach($tempContactGroups as $groupID) {
				if(!is_array($groupList) || !in_array($groupID, $groupList)) {
					$groupList[$groupID] = $groupID;
				}
			}
		}
		return true;
	}
	else {
		return false;	// Should never really get here
	}
}

// Function recursively gets the inherited template values, given a template
function get_service_template_inherited_servicegroups_list($service_template_id, &$groupList) {
	$query = "SELECT * FROM nagios_service_templates WHERE service_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$tempTemplateInfo = $result->fields;
		if(isset($tempTemplateInfo['use_template_id'])) {
			$this->get_service_template_inherited_servicegroups_list($tempTemplateInfo['use_template_id'], $groupList);
		}
		$tempTemplateName = $tempTemplateInfo['template_name'];		
		$query = "SELECT servicegroup_id FROM nagios_service_template_servicegroups WHERE service_template_id = '$service_template_id'";
		$result = $this->dbConnection->Execute($query);
		// While loop
		while (! $result->EOF)
		{
			$tempContactGroups[] = $result->fields['servicegroup_id'];
			$result->MoveNext();
		}
		if(count($tempContactGroups)) {
			foreach($tempContactGroups as $groupID) {
				if(!is_array($groupList) || !in_array($groupID, $groupList)) {
					$groupList[$groupID] = $groupID;
				}
			}
		}
		return true;
	}
	else {
		return false;	// Should never really get here
	}
}

function get_contact_info($contact_id, &$contactinfo) {
	
	$query = "SELECT * FROM nagios_contacts WHERE contact_id = '$contact_id'";
	$result = $this->dbConnection->Execute($query);
	$contactinfo = $result->fields;
}

function get_contactgroup_info($contactgroup_id, &$contactgroupinfo) {
	
	$query = "SELECT * FROM nagios_contactgroups WHERE contactgroup_id = '$contactgroup_id'";
	$result = $this->dbConnection->Execute($query);
	$contactgroupinfo = $result->fields;
}


function get_hostgroup_info($hostgroup_id, &$hostgroupinfo) {
	
	$query = "SELECT * FROM nagios_hostgroups WHERE hostgroup_id = '$hostgroup_id'";
	$result = $this->dbConnection->Execute($query);
	$hostgroupinfo = $result->fields;
}

function get_servicegroup_info($servicegroup_id, &$servicegroupinfo) {
	
	$query = "SELECT * FROM nagios_servicegroups WHERE servicegroup_id = '$servicegroup_id'";
	$result = $this->dbConnection->Execute($query);
	$servicegroupinfo = $result->fields;
}

function get_service_info($service_id, &$service_info) {
	
	$query = "SELECT * FROM nagios_services WHERE service_id = '$service_id'";
	$result = $this->dbConnection->Execute($query);
	if($this->dbConnection->Affected_Rows()) {
		$service_info = $result->fields;
		return true;
	}
	else {
		return false;
	}
}

function get_command_name($command_id) {
	
	$query = "SELECT command_name FROM nagios_commands WHERE command_id = '$command_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['command_name'];
}



function return_contact_name($contact_id) {
	
	$query = "SELECT contact_name FROM nagios_contacts WHERE contact_id = '$contact_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['contact_name'];
}

function return_period_name($timeperiod_id) {
	
	$query = "SELECT timeperiod_name FROM nagios_timeperiods WHERE timeperiod_id = '$timeperiod_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['timeperiod_name'];
}

function return_service_description($service_id) {
	
	$query = "SELECT service_description FROM nagios_services WHERE service_id = '$service_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['service_description'];
}

function return_escalation_description($escalation_id) {
	
	$query = "SELECT escalation_description FROM nagios_escalations WHERE escalation_id = '$escalation_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['escalation_description'];
}

function return_contactgroup_name($contactgroup_id) {
	
	$query = "SELECT contactgroup_name FROM nagios_contactgroups WHERE contactgroup_id = '$contactgroup_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['contactgroup_name'];
}

function return_servicegroup_name($servicegroup_id) {
	
	$query = "SELECT servicegroup_name FROM nagios_servicegroups WHERE servicegroup_id = '$servicegroup_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['servicegroup_name'];
}


function return_hostgroup_name($hostgroup_id) {
	
	$query = "SELECT hostgroup_name FROM nagios_hostgroups WHERE hostgroup_id = '$hostgroup_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['hostgroup_name'];
}

function return_host_template_dependency($host_template_id, $target_host_id) {
	
	$query = "SELECT dependency_id FROM nagios_dependencies WHERE host_template_id = '$host_template_id' AND target_host_id = '$target_host_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['dependency_id'];
}

function return_host_template_escalation($host_template_id, $escalation_description) {
	
	$query = "SELECT escalation_id FROM nagios_escalations WHERE host_template_id = '$host_template_id' AND escalation_description = '$escalation_description' AND service_id IS NULL";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['escalation_id'];
}

function return_service_template_escalation($service_template_id, $escalation_description) {
	
	$query = "SELECT escalation_id FROM nagios_escalations WHERE service_template_id = '$service_template_id' AND escalation_description = '$escalation_description' AND service_id IS NULL";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['escalation_id'];
}

function return_service_escalation($service_id, $escalation_description) {
	
	$query = "SELECT escalation_id FROM nagios_escalations WHERE service_id = '$service_id' AND escalation_description = '$escalation_description'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['escalation_id'];
}

function return_host_escalation($host_id, $escalation_description) {
	
	$query = "SELECT escalation_id FROM nagios_escalations WHERE host_id = '$host_id' AND escalation_description = '$escalation_description' AND service_id IS NULL";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['escalation_id'];
}


function return_host_dependency($host_id, $target_host_id) {
	
	$query = "SELECT dependency_id FROM nagios_dependencies WHERE host_id = '$host_id' AND target_host_id = '$target_host_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['dependency_id'];
}

function return_service_dependency($service_id, $target_host_id, $target_service_id) {
	
	$query = "SELECT dependency_id FROM nagios_dependencies WHERE service_id = '$service_id' AND target_service_id = '$target_service_id' AND target_host_id = '$target_host_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['dependency_id'];
}

function return_service_template_dependency($service_template_id, $target_service_id) {
	
	$query = "SELECT dependency_id FROM nagios_dependencies WHERE service_template_id = '$service_template_id' AND target_service_id = '$target_service_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['dependency_id'];
}


function return_hostgroup_alias($hostgroup_id) {
	
	$query = "SELECT alias FROM nagios_hostgroups WHERE hostgroup_id = '$hostgroup_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['alias'];
}

function return_contactgroup_alias($contactgroup_id) {
	
	$query = "SELECT alias FROM nagios_contactgroups WHERE contactgroup_id = '$contactgroup_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['alias'];
}	

function return_servicegroup_alias($servicegroup_id) {
	
	$query = "SELECT alias FROM nagios_servicegroups WHERE servicegroup_id = '$servicegroup_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['alias'];
}	


function return_contact_alias($contact_id) {
	
	$query = "SELECT alias FROM nagios_contacts WHERE contact_id = '$contact_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['alias'];
}

function return_host_name($host_id) {
	
	$query = "SELECT host_name FROM nagios_hosts WHERE host_id = '$host_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['host_name'];
}

function return_host_template_name($host_template_id) {
	
	$query = "SELECT template_name FROM nagios_host_templates WHERE host_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['template_name'];
}

function return_service_template_name($service_template_id) {
	
	$query = "SELECT template_name FROM nagios_service_templates WHERE service_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['template_name'];
}

function return_host_alias($host_id) {
	
	$query = "SELECT alias FROM nagios_hosts WHERE host_id = '$host_id'";
	$result = $this->dbConnection->Execute($query);
	return $result->fields['alias'];
}

function get_host_template_list(&$template_list) {
	$template_list = NULL;
	
	$query = "SELECT host_template_id, template_name, template_description FROM nagios_host_templates";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$template_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function get_service_template_list(&$template_list) {
	$template_list = NULL;
	
	$query = "SELECT service_template_id, template_name, template_description FROM nagios_service_templates";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$template_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function return_contactgroup_member_list($group_id, &$member_list) {
	
	$member_list = NULL;
	$query = "SELECT * FROM nagios_contactgroup_membership WHERE contactgroup_id = '$group_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$member_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function return_hostgroup_member_list($hostgroup_id, &$member_list) {
	$member_list = NULL;
	
	$query = "SELECT * FROM nagios_hostgroup_membership WHERE hostgroup_id = '$hostgroup_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$member_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function return_servicegroup_member_list($servicegroup_id, &$member_list) {
	$member_list = NULL;
	
	$query = "SELECT * FROM nagios_service_servicegroups WHERE servicegroup_id = '$servicegroup_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$member_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}	
	

function return_hostgroup_contactgroups_list($hostgroup_id, &$groups_list) {
	$groups_list = NULL;
	
	$query = "SELECT * FROM nagios_hostgroup_contactgroups WHERE hostgroup_id = '$hostgroup_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$groups_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}


function return_host_contactgroups_list($host_id, &$groups_list) {
	$groups_list = NULL;
	
	$query = "SELECT * FROM nagios_host_contactgroups WHERE host_id = '$host_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$groups_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function return_service_contactgroups_list($service_id, &$groups_list) {
	$groups_list = NULL;
	
	$query = "SELECT * FROM nagios_service_contactgroups WHERE service_id = '$service_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$groups_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function return_escalation_contactgroups_list($escalation_id, &$groups_list) {
	$groups_list = NULL;
	
	$query = "SELECT * FROM nagios_escalation_contactgroups WHERE escalation_id = '$escalation_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$groups_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function return_host_template_contactgroups_list($host_template_id, &$groups_list) {
	$groups_list = NULL;
	
	$query = "SELECT * FROM nagios_host_template_contactgroups WHERE host_template_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$groups_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function return_service_template_contactgroups_list($service_template_id, &$groups_list) {
	$groups_list = NULL;
	
	$query = "SELECT * FROM nagios_service_template_contactgroups WHERE service_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$groups_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function return_service_template_servicegroups_list($service_template_id, &$groups_list) {
	$groups_list = NULL;
	
	$query = "SELECT * FROM nagios_service_template_servicegroups WHERE service_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$groups_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function return_service_servicegroups_list($service_id, &$groups_list) {
	$groups_list = NULL;
	
	$query = "SELECT * FROM nagios_service_servicegroups WHERE service_id = '$service_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$groups_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function return_host_template_dependencies_list($host_template_id, &$dependencies_list) {
	$dependencies_list = NULL;
	$query = "SELECT * FROM nagios_dependencies WHERE host_template_id = '$host_template_id' AND service_id IS NULL";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$dependencies_list[$result->fields['host_template_id']] = $result->fields;
		$result->MoveNext();
	}
	
	return true;
}

function return_host_template_escalations_list($host_template_id, &$escalations_list) {
	$dependencies_list = NULL;
	$query = "SELECT * FROM nagios_escalations WHERE host_template_id = '$host_template_id' AND service_id IS NULL";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$escalations_list[$result->fields['host_template_id']] = $result->fields;
		$result->MoveNext();
	}
	
	return true;	
}

function return_service_template_escalations_list($service_template_id, &$escalations_list) {
	$dependencies_list = NULL;
	$query = "SELECT * FROM nagios_escalations WHERE service_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$escalations_list[$result->fields['service_template_id']] = $result->fields;
		$result->MoveNext();
	}
	
	return true;	
}

function return_service_escalations_list($service_id, &$escalations_list) {
	$dependencies_list = NULL;
	$query = "SELECT * FROM nagios_escalations WHERE service_id = '$service_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$escalations_list[$result->fields['service_id']] = $result->fields;
		$result->MoveNext();
	}
	
	return true;	
}

function return_host_escalations_list($host_id, &$escalations_list) {
	$dependencies_list = NULL;
	$query = "SELECT * FROM nagios_escalations WHERE host_id = '$host_id' AND service_id IS NULL";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$escalations_list[$result->fields['host_id']] = $result->fields;
		$result->MoveNext();
	}
	
	return true;	
}

function return_service_template_dependencies_list($service_template_id, &$dependencies_list) {
	$dependencies_list = NULL;
	$query = "SELECT * FROM nagios_dependencies WHERE service_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$dependencies_list[$result->fields['target_service_id']] = $result->fields;
		$result->MoveNext();
	}
	
	return true;	
}

function return_host_dependencies_list($host_id, &$dependencies_list) {
	$dependencies_list = NULL;
	$query = "SELECT * FROM nagios_dependencies WHERE host_id = '$host_id' AND service_id IS NULL";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$dependencies_list[$result->fields['host_id']] = $result->fields;
		$result->MoveNext();
	}
	
	return true;	
}

function return_service_dependencies_list($service_id, &$dependencies_list) {
	$dependencies_list = NULL;
	$query = "SELECT * FROM nagios_dependencies WHERE service_id = '$service_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$dependencies_list[$result->fields['host_id']] = $result->fields;
		$result->MoveNext();
	}
	
	return true;	
}

function get_contact_list(&$contact_list) {
	
	$query = "SELECT contact_id, contact_name, alias FROM nagios_contacts";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$contact_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function get_host_list(&$host_list) {
	$host_list = NULL;
	// This will be REALLY scary for a systems with lots of hosts
	
	$query = "SELECT host_id, host_name, alias FROM nagios_hosts";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$host_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function get_hostgroup_list(&$hostgroups_list) {
	$hostgroups_list = NULL;
	
	$query = "SELECT hostgroup_id, hostgroup_name, alias FROM nagios_hostgroups";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$hostgroups_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function get_servicegroup_list(&$servicegroups_list) {
	$servicegroups_list = NULL;
	
	$query = "SELECT servicegroup_id, servicegroup_name, alias FROM nagios_servicegroups";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$servicegroups_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function get_services_list(&$services_list) {
	// This will be a memory hog for those with a lot of servers+hosts
	$services_list = NULL;
	
	$query = "SELECT service_id, service_description FROM nagios_services";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$services_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function get_dependencies_list(&$dependencies_list) {
	// This will be a memory hog for those with a lot of servers+hosts
	$dependencies_list = NULL;
	
	$query = "SELECT dependency_id FROM nagios_dependencies";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$dependencies_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function get_escalations_list(&$escalations_list) {
	// This will be a memory hog for those with a lot of servers+hosts
	$escalations_list = NULL;
	
	$query = "SELECT escalation_id FROM nagios_escalations";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		$escalations_list[] = $result->fields;
		$result->MoveNext();
	}
	
	return 1;
}

function get_contacts_notification_commands($contact_id, &$command_list) {
	$command_list = NULL;
	
	$query = "SELECT contact_notification_command_id, command_id, notification_type FROM nagios_contacts_notification_commands WHERE contact_id = '$contact_id'";
	$result = $this->dbConnection->Execute($query);
	while (! $result->EOF)
	{
		if($result->fields['notification_type'] == 'host')
			$command_list['host'][] = $result->fields;
		else 
			$command_list['service'][] = $result->fields;
		$result->MoveNext();
	}
	return 1;
}

function contact_has_notification_command($contact_id, $notification_command) {
	
	$query = "SELECT contact_notification_command_id  FROM nagios_contacts_notification_commands WHERE command_id = '${notification_command['command_id']}' AND contact_id = '$contact_id' AND notification_type = '${notification_command['notification_type']}'";
	$result = $this->dbConnection->Execute($query);	
	if(!$result->EOF) {
		return true;
	}
	else {
		return false;
	}
}

function contactgroup_has_member($contactgroup_id, $contact_id) {
	
	$query = "SELECT contact_id FROM nagios_contactgroup_membership WHERE contactgroup_id = '${contactgroup_id}' AND contact_id = '${contact_id}'";
	$result = $this->dbConnection->Execute($query);	
	if(!$result->EOF) {
		return true;
	}
	else {
		return false;
	}
}

function hostgroup_has_contactgroup($hostgroup_id, $contactgroup_id) {
	
	$query = "SELECT contactgroup_id FROM nagios_hostgroup_contactgroups WHERE contactgroup_id = '${contactgroup_id}' AND hostgroup_id = '${hostgroup_id}'";
	$result = $this->dbConnection->Execute($query);	
	if(!$result->EOF) {
		return true;
	}
	else {
		return false;
	}
}

function host_has_contactgroup($host_id, $contactgroup_id) {
	
	$query = "SELECT contactgroup_id FROM nagios_host_contactgroups WHERE contactgroup_id = '${contactgroup_id}' AND host_id = '${host_id}'";
	$result = $this->dbConnection->Execute($query);	
	if(!$result->EOF) {
		return true;
	}
	else {
		return false;
	}
}

function host_template_has_contactgroup($host_template_id, $contactgroup_id) {
	
	$query = "SELECT contactgroup_id FROM nagios_host_template_contactgroups WHERE contactgroup_id = '${contactgroup_id}' AND host_template_id = '${host_template_id}'";
	$result = $this->dbConnection->Execute($query);	
	if(!$result->EOF) {
		return true;
	}
	else {
		return false;
	}
}

function service_template_has_contactgroup($service_template_id, $contactgroup_id) {
	
	$query = "SELECT contactgroup_id FROM nagios_service_template_contactgroups WHERE contactgroup_id = '${contactgroup_id}' AND service_template_id = '${service_template_id}'";
	$result = $this->dbConnection->Execute($query);	
	if(!$result->EOF) {
		return true;
	}
	else {
		return false;
	}
}

function service_template_has_servicegroup($service_template_id, $servicegroup_id) {
	
	$query = "SELECT servicegroup_id FROM nagios_service_template_servicegroups WHERE servicegroup_id = '${servicegroup_id}' AND service_template_id = '${service_template_id}'";
	$result = $this->dbConnection->Execute($query);	
	if(!$result->EOF) {
		return true;
	}
	else {
		return false;
	}
}

function host_has_service($host_id, $service_id) {
	
	$query = "SELECT host_id FROM nagios_host_services WHERE host_id = '${host_id}' AND service_id = '${service_id}'";
	$result = $this->dbConnection->Execute($query);	
	if(!$result->EOF) {
		return true;
	}
	else {
		return false;
	}
}

function hostgroup_has_service($hostgroup_id, $service_id) {
	
	$query = "SELECT hostgroup_id FROM nagios_hostgroup_services WHERE hostgroup_id = '$hostgroup_id' AND service_id = '${service_id}'";
	$result = $this->dbConnection->Execute($query);	
	if(!$result->EOF) {
		return true;
	}
	else {
		return false;
	}
}


function service_has_contactgroup($service_id, $contactgroup_id) {
	
	$query = "SELECT contactgroup_id FROM nagios_service_contactgroups WHERE contactgroup_id = '${contactgroup_id}' AND service_id = '${service_id}'";
	$result = $this->dbConnection->Execute($query);	
	if(!$result->EOF) {
		return true;
	}
	else {
		return false;
	}
}

function escalation_has_contactgroup($escalation_id, $contactgroup_id) {
	
	$query = "SELECT contactgroup_id FROM nagios_escalation_contactgroups WHERE contactgroup_id = '${contactgroup_id}' AND escalation_id = '${escalation_id}'";
	$result = $this->dbConnection->Execute($query);	
	if(!$result->EOF) {
		return true;
	}
	else {
		return false;
	}
}

function service_has_servicegroup($service_id, $servicegroup_id) {
	
	$query = "SELECT servicegroup_id FROM nagios_service_servicegroups WHERE servicegroup_id = '${servicegroup_id}' AND service_id = '${service_id}'";
	$result = $this->dbConnection->Execute($query);	
	if(!$result->EOF) {
		return true;
	}
	else {
		return false;
	}
}

function host_has_hostgroup($host_id, $hostgroup_id) {
	
	$query = "SELECT host_id FROM nagios_hostgroup_membership WHERE host_id = '${host_id}' AND hostgroup_id = '${hostgroup_id}'";
	$result = $this->dbConnection->Execute($query);	
	if(!$result->EOF) {
		return true;
	}
	else {
		return false;
	}
}

function host_template_has_hostgroup($host_template_id, $hostgroup_id) {
	
	$query = "SELECT host_template_id FROM nagios_hostgroup_template_membership WHERE host_template_id = '${host_template_id}' AND hostgroup_id = '${hostgroup_id}'";
	$result = $this->dbConnection->Execute($query);	
	if(!$result->EOF) {
		return true;
	}
	else {
		return false;
	}
}

function hostgroup_has_member($hostgroup_id, $host_id) {
	
	$query = "SELECT host_id FROM nagios_hostgroup_membership WHERE hostgroup_id = '${hostgroup_id}' AND host_id = '${host_id}'";
	$result = $this->dbConnection->Execute($query);	
	if(!$result->EOF) {
		return true;
	}
	else {
		return false;
	}
}

function add_contacts_notification_command($contact_id, $notification_command) {
	
	$query = "INSERT INTO nagios_contacts_notification_commands (";
	$query .= implode(", ", array_keys($notification_command));
   	$query .= ") VALUES ('";
  	$query .= implode("', '", array_values($notification_command));
   	$query .= "')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}


function add_contactgroup_member($contactgroup_id, $contact_id) {
	
	$query = "INSERT INTO nagios_contactgroup_membership (contactgroup_id, contact_id) VALUES ('$contactgroup_id', '$contact_id')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function add_hostgroup_member($hostgroup_id, $host_id) {
	
	$query = "INSERT INTO nagios_hostgroup_membership (hostgroup_id, host_id) VALUES ('$hostgroup_id', '$host_id')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function add_hostgroup_template_member($hostgroup_id, $host_template_id) {
	
	$query = "INSERT INTO nagios_hostgroup_template_membership (hostgroup_id, host_template_id) VALUES ('$hostgroup_id', '$host_template_id')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function add_hostgroup_contactgroup($hostgroup_id, $contactgroup_id) {
	
	$query = "INSERT INTO nagios_hostgroup_contactgroups (hostgroup_id, contactgroup_id) VALUES ('$hostgroup_id', '$contactgroup_id')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function add_host_contactgroup($host_id, $contactgroup_id) {
	
	$query = "INSERT INTO nagios_host_contactgroups (host_id, contactgroup_id) VALUES ('$host_id', '$contactgroup_id')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function add_host_template_contactgroup($host_template_id, $contactgroup_id) {
	
	$query = "INSERT INTO nagios_host_template_contactgroups (host_template_id, contactgroup_id) VALUES ('$host_template_id', '$contactgroup_id')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function add_service_template_contactgroup($service_template_id, $contactgroup_id) {
	
	$query = "INSERT INTO nagios_service_template_contactgroups (service_template_id, contactgroup_id) VALUES ('$service_template_id', '$contactgroup_id')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function add_service_template_servicegroup($service_template_id, $servicegroup_id) {
	
	$query = "INSERT INTO nagios_service_template_servicegroups (service_template_id, servicegroup_id) VALUES ('$service_template_id', '$servicegroup_id')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;
}

function add_service_contactgroup($service_id, $contactgroup_id) {
	
	$query = "INSERT INTO nagios_service_contactgroups (service_id, contactgroup_id) VALUES ('$service_id', '$contactgroup_id')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;

}

function add_escalation_contactgroup($escalation_id, $contactgroup_id) {
	
	$query = "INSERT INTO nagios_escalation_contactgroups (escalation_id, contactgroup_id) VALUES ('$escalation_id', '$contactgroup_id')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;

}

function add_service_servicegroup($service_id, $servicegroup_id) {
	
	$query = "INSERT INTO nagios_service_servicegroups (service_id, servicegroup_id) VALUES ('$service_id', '$servicegroup_id')";
	$result = $this->dbConnection->Execute($query);
	if($result)
		return true;
	else 
		return false;

}

function build_object_inheritance(&$dependentObject, $targetObjectTree) {
	// Build object inheritance
	if(isset($dependentObject['use'])) {
		// First we get to the end of the inheritance chain.
		$tmpObject = $dependentObject;
		$subcounter = 0;
		$useStack[$subcounter] = $tmpObject;
		while(isset($tmpObject['use'])) {
			$found = 0;
			// Now we have to find the dependency
			foreach($targetObjectTree as $loopObject) {
				if(isset($loopObject['name']) && $loopObject['name'] == $tmpLoopObject['use']) {
					$tmpObject = $loopObject;
					$found = 1;
				}
			}
			if(!$found)
			unset($tmpObject['use']);	// Didn't find the top parent, so we'll toss it.
			$subcounter++;
			$useStack[$subcounter] = $tmpObject;
		}
		// At end of dependency list, start assigning values
		$numOfDependencies = count($useStack);
		$dependentObject = array();
		for($subcounter = ($numOfDependencies-1); $subcounter >= 0; $subcounter--)
			$dependentObject = array_merge($dependentObject, $useStack[$subcounter]);
		unset($useStack);
	}
	// Remove any use or registered items
	unset($dependentObject['use']);
	unset($dependentObject['name']);
	unset($dependentObject['register']);
}

function get_host_icon_image($host_id, &$host_icon_image) {
	
	$query = "SELECT icon_image FROM nagios_hosts_extended_info WHERE host_id = '$host_id'";
	$result = $this->dbConnection->Execute($query);
	if($result->fields['icon_image'] != '') {
		$host_icon_image = $result->fields['icon_image'];
		return true;
	}
	else 
		return false;
}

function get_service_icon_image($service_id, &$service_icon_image) {
	
	$query = "SELECT icon_image FROM nagios_services_extended_info WHERE service_id = '$service_id'";
	$result = $this->dbConnection->Execute($query);
	if($result->fields['icon_image'] != '') {
		$service_icon_image = $result->fields['icon_image'];
		return true;
	}
	else 
		return false;
}


function get_host_template_icon_image($host_template_id, &$host_template_icon_image) {
	
	$query = "SELECT icon_image FROM nagios_hosts_template_extended_info WHERE host_id = '$host_template_id'";
	$result = $this->dbConnection->Execute($query);
	if($result->fields['icon_image'] != '') {
		$host_template_icon_image = $result->fields['icon_image'];
		return true;
	}
	else 
		return false;
}

function get_service_template_icon_image($service_template_id, &$service_template_icon_image) {
	
	$query = "SELECT icon_image FROM nagios_services_template_extended_info WHERE service_template_id = '$service_template_id'";
	$result = $this->dbConnection->Execute($query);
	if($result->fields['icon_image'] != '') {
		$service_template_icon_image = $result->fields['icon_image'];
		return true;
	}
	else 
		return false;
}
	
}
$fruity = new fruityclass;
?>
